@@ -1,13 +1,13 @@
 package Galileo;
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = 0.006;
+our $VERSION = 0.007;
 $VERSION = eval $VERSION;
 
 use File::Basename 'dirname';
-use File::Spec::Functions 'catdir';
+use File::Spec::Functions qw'rel2abs catdir';
 use File::ShareDir 'dist_dir';
-use Cwd 'abs_path';
+use Cwd;
 
 has db => sub {
   my $self = shift;
@@ -23,31 +23,52 @@ has db => sub {
   return $schema;
 };
 
-has config_file => $ENV{GALILEO_CONFIG} || abs_path 'galileo.conf';
+has home_path => $ENV{GALILEO_HOME} || getcwd;
+
+has config_file => sub {
+  my $self = shift;
+  return $ENV{GALILEO_CONFIG} if $ENV{GALILEO_CONFIG}; 
+
+  return rel2abs( 'galileo.conf', $self->home_path );
+};
 
 sub startup {
   my $app = shift;
 
+  # set home folder
+  $app->home->parse( $app->home_path );
+
+  {
+    # setup logging path
+    # code stolen from Mojolicious.pm
+    my $mode = $app->mode;
+
+    $app->log->path($app->home->rel_file("log/$mode.log"))
+      if -w $app->home->rel_file('log');
+  }
+
   $app->plugin( Config => { 
     file => $app->config_file,
     default => {
       db_schema  => 'Galileo::DB::Schema',
       db_connect => [
-        'dbi:SQLite:dbname=galileo.db',
+        'dbi:SQLite:dbname=' . $app->home->rel_file( 'galileo.db' ),
         undef,
         undef,
         { sqlite_unicode => 1 },
       ],
-      secret     => 'MySecret',
+      secret => 'MySecret',
     },
   });
 
-  # use content from directories under lib/Galileo/files or using File::ShareDir
-  $app->home->parse(catdir(dirname(__FILE__), 'Galileo'));
   {
-    my $public = $app->home->rel_dir('files/public');
+    # use content from directories under lib/Galileo/files or using File::ShareDir
+    my $lib_base = catdir(dirname(rel2abs(__FILE__)), 'Galileo', 'files');
+
+    my $public = catdir($lib_base, 'public');
     $app->static->paths->[0] = -d $public ? $public : catdir(dist_dir('Galileo'), 'public');
-    my $templates = $app->home->rel_dir('files/templates');
+
+    my $templates = catdir($lib_base, 'templates');
     $app->renderer->paths->[0] = -d $templates ? $templates : catdir(dist_dir('Galileo'), 'templates');
   }
 
@@ -154,6 +175,7 @@ sub startup {
   $if_admin->any( '/admin/pages' )->to('admin#pages');
   $if_admin->any( '/admin/user/:name' )->to('admin#user');
   $if_admin->websocket( '/store/user' )->to('admin#store_user');
+  $if_admin->websocket( '/remove/page' )->to('admin#remove_page');
 }
 
 1;
@@ -185,23 +207,41 @@ when using L<App::cpanminus>. Of course you can use your favorite CPAN client or
 
 =head1 SETUP
 
-L<Galileo> installs a helper script C<galileo>. It inherits from the L<mojo> command, but it provides extra functions specifically for use with Galileo.
+=head2 Environment
 
-=head2 config
+Although most of L<Galileo> is controlled by a configuration file, a few properties must be set before that file can be read. These properties are controlled by the following environment variables.
+
+=over 
+
+=item C<GALILEO_HOME>
+
+This is the directory where L<Galileo> expects additional files. These include the configuration file and log files. The default value is the current working directory (C<cwd>).
+
+=item C<GALILEO_CONFIG>
+
+This is the full path to a configuration file. The default is a file named F<galileo.conf> in the C<GALILEO_HOME> path, however this file need not actually exist, defaults may be used instead. This file need not be written by hand, it may be generated by the C<galileo config> command.
+
+=back
+
+=head2 The F<galileo> command line application
+
+L<Galileo> installs a command line application, C<galileo>. It inherits from the L<mojo> command, but it provides extra functions specifically for use with Galileo.
+
+=head3 config
 
  $ galileo config [options]
 
-This command writes a configuration file in your current working directory. It uses the preset defaults for all values, except that it prompts for a secret. This can be any string, however stronger is better. You do not need to memorize it or remember it. This secret protects the cookies employed by Galileo from being tampered with on the client side.
+This command writes a configuration file in your C<GALILEO_HOME> path. It uses the preset defaults for all values, except that it prompts for a secret. This can be any string, however stronger is better. You do not need to memorize it or remember it. This secret protects the cookies employed by Galileo from being tampered with on the client side.
 
 L<Galileo> does not need to be configured, however it is recommended to do so to set your application's secret. 
 
 The C<--force> option may be passed to overwrite any configuration file in the current working directory. The default is to die if such a configuration file is found.
 
-=head2 setup
+=head3 setup
 
  $ galileo setup
 
-Run C<galileo setup> to setup a database. This step is required. It will use the default DBI settings (SQLite) or whatever is setup in the configuration file generated by the C<config> command.
+This step is required. Run C<galileo setup> to setup a database. It will use the default DBI settings (SQLite) or whatever is setup in the C<GALILEO_CONFIG> configuration file.
 
 =head1 RUNNING THE APPLICATION
 
@@ -213,11 +253,11 @@ You may also use L<morbo> (Mojolicious' development server) or L<hypnotoad> (Moj
 
  $ hypnotoad `which galileo`
 
-or replace C<hypnotoad> with your server of choice.
+where you may replace C<hypnotoad> with your server of choice.
 
-=head2 Configuration
+=head2 Logging
 
-L<Galileo> will look for a configuration file named F<galileo.conf> in the current working directory. To change this behavior set the environment variable C<GALILEO_CONFIG> to the full path to your configuration file. Note that the `galileo config` action will respect this variable and will write a configuration file to that full file path if detected.
+Logging in L<Galileo> is the same as in L<Mojolicious|Mojolicious::Lite/Logging>. Messages will be printed to C<STDERR> unless a directory named F<log> exists in the C<GALILEO_HOME> path, in which case messages will be logged to a file in that directory.
 
 =head1 TECHNOLOGIES USED
 
